@@ -65,7 +65,10 @@ class MySQL2DatacatalogCli(datacatalog_cli.DatacatalogCli):
             required=True)
         parser.add_argument('--datacatalog-entry-group-id',
                             help='Entry group ID to be used for your Google '
-                            'Cloud Datacatalog')
+                            'Data Catalog')
+        parser.add_argument('--datacatalog-entry-resource-url-prefix',
+                            help='Entry resource URL prefix '
+                            'used in the ingested Data Catalog Entries')
         parser.add_argument(
             '--mysql-host',
             help='Your mysql server host, this is required even'
